<?php

class Everyware_Dashboard {

    private $versions_url = 'https://composer.infomaker.io/versions.json';

    public function __construct() {

        add_action( 'wp_dashboard_setup', [
            &$this,
            'ew_add_dashboard_widget'
        ] );
    }

    /**
     * Add a widget to the admin dashboard.
     */
    function ew_add_dashboard_widget() {
        wp_add_dashboard_widget( 'ew_dashboard_widget', 'Everyware', [
                &$this,
                'ew_dashboard_widget_render'
            ] );
    }

    /**
     * Outputs data to dashboard widget.
     */
    function ew_dashboard_widget_render() {

        $key = 'ew_latest_version';
        if ( false === ( $latest_version = get_transient( $key ) ) ) {
            $response = wp_remote_get( $this->versions_url, [
                'timeout' => 3
            ] );

            if ( is_array( $response ) ) {
                $plugins = json_decode( $response['body'] );
                if ( $plugins !== null ) {
                    foreach ( $plugins as $plugin ) {
                        if ( $plugin->name === 'infomaker/everyware' ) {
                            usort( $plugin->versions, 'version_compare' );
                            $latest_version = $plugin->versions[count( $plugin->versions ) - 1];
                            set_transient( $key, $latest_version, 86400 );
                        }
                    }
                }
            }
        }

        print '<p>';
        print __( 'Currently running Everyware version: ', 'every' ) . '<strong>' . EVERY_VERSION . '</strong>';
        print '</p>';
        if ( $latest_version === false ) {
            print '<p>';
            print __( 'Could not fetch version information, check back later!', 'every' );
            print '</p>';
        } else if ( $latest_version === EVERY_VERSION ) {
            print '<p>';
            print __( 'Up to date with latest release.', 'every' );
            print '</p>';
        } else if ( version_compare( EVERY_VERSION, $latest_version, '<' ) ) {
            print '<p>';
            print __( 'There is a newer version of Everyware available, update or contact Infomaker for more information.', 'every' ) . ' ';
            print '<strong>' . __( 'Latest version', 'every' ) . ': ' . $latest_version . '</strong>';
            print '</p>';
        }

        print '<hr>';
        print '<p style="color: #ddd;">';
        print '<a href="https://docs.infomaker.io/everyware/plugins/everyware/" target="_blank">Documentation <span class="screen-reader-text">(opens in a new window)</span><span aria-hidden="true" class="dashicons dashicons-external"></span></a>';
        print ' | ';
        print '<a href="https://docs.infomaker.io/everyware/plugins/everyware/changelog" target="_blank">Changelog <span class="screen-reader-text">(opens in a new window)</span><span aria-hidden="true" class="dashicons dashicons-external"></span></a>';
        print '</p>';
    }
}
